@@ -1,4 +1,4 @@
-import django.db.models.fields as django_fields
+from django.db import models as django_models
 
 
 def default_cache_func(
@@ -8,7 +8,6 @@ def default_cache_func(
 ):
     redis_model = create_redis_model_from_django_model(django_model, redis_root)
     redis_dicts = redis_root.get(redis_model, return_dict=True)
-    print(len(redis_dicts.keys()))
     # cache_to_django(
     #     django_model,
     #     redis_dicts
@@ -75,13 +74,13 @@ def redis_dict_to_django_params(
     for django_field in django_model._meta.get_fields():
         django_field_name = django_field.name
         if django_field_name in redis_dict.keys():
-            if django_field.__class__ == django_fields.ForeignKey:
+            if django_field.__class__ == django_models.ForeignKey:
                 foreign_key_model = django_field.remote_field.model
                 redis_foreign_key_instance = redis_dict[django_field_name]
                 django_foreign_key_instance = update_or_create_django_instance_from_redis_instance(
                     redis_foreign_key_instance, foreign_key_model)
                 django_params[django_field_name] = django_foreign_key_instance
-            elif django_field.__class__ == django_fields.ManyToManyField:
+            elif django_field.__class__ == django_models.ManyToManyField:
                 many_to_many_model = django_field.remote_field.model
                 django_many_to_many_instances = []
                 redis_many_to_many_instances = redis_dict[django_field.name]
@@ -95,19 +94,6 @@ def redis_dict_to_django_params(
                 django_params[django_field_name] = value
     return django_params, django_many_to_many_params
 
-    redis_dict = {
-        'owner': get_or_create_redis_dict_custom_user(redis_root, django_instance, django_instance.owner),
-        'platform': django_instance.platform,
-        'username': django_instance.username,
-        'status': django_instance.status,
-        'level': django_instance.level,
-        'last_checked_in': django_instance.last_checked_in,
-        'last_task_completed_in': django_instance.last_task_completed_in,
-        'ddos_account_will_be_available_in': django_instance.ddos_account_will_be_available_in,
-        'created': django_instance.created
-    }
-    return redis_dict
-
 
 def update_django_many_to_many(
         django_model,
@@ -173,10 +159,10 @@ def django_instance_field_to_redis_value(
         redis_root,
         create_redis_model_from_django_model
 ):
-    print(django_instance.__class__._meta.get_fields())
+
     django_field_value = getattr(django_instance, django_field.name)
     redis_value = django_field_value
-    if django_field.__class__ == django_fields.ForeignKey:
+    if django_field.__class__ == django_models.ForeignKey:
         django_foreign_key_instance = django_field_value
         redis_value = get_or_create_redis_instance_from_django_instance(
             django_foreign_key_instance,
@@ -184,7 +170,7 @@ def django_instance_field_to_redis_value(
             create_redis_model_from_django_model
         )
 
-    elif django_field.__class__ == django_fields.ManyToManyField:
+    elif django_field.__class__ == django_models.ManyToManyField:
         redis_value = [
             get_or_create_redis_instance_from_django_instance(
                 django_many_to_many_instance,
@@ -207,6 +193,7 @@ def django_instance_to_redis_params(
     ]
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if django_field.__class__.__name__ not in exclude_fields:
+            print(django_field.__class__.__name__)
             redis_param = django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
