@@ -430,7 +430,6 @@ class RedisRoot:
 
     def check_cache(self):
         django_models_to_cache = self._get_django_models_to_cache()
-        print(f'{django_models_to_cache = }')
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
 
@@ -488,7 +487,6 @@ class RedisRoot:
                 else:
                     redis_field = RedisString
 
-                print(django_field.__class__.__name__)
                 if redis_field:
                     redis_field = type(
                         django_field.__class__.__name__,
